#
# spec file for package xtl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xtl
Version:        0.7.7
Release:        1.2
Summary:        The x template library
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
URL:            https://github.com/xtensor-stack/xtl
Source0:        https://github.com/xtensor-stack/xtl/archive/refs/tags/%{version}/xtl-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doctest-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkg-config
BuildRequires:  python3-breathe
BuildRequires:  cmake(nlohmann_json)

%description
Basic tools (containers, algorithms) used by other quantstack packages.

%package        devel
Summary:        The x template library
Group:          Development/Languages/C and C++
Requires:       cmake(nlohmann_json)
BuildArch:      noarch

%description    devel
Basic tools (containers, algorithms) used by other quantstack packages.

%package        doc
Summary:        Documentation for xtl
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
Basic tools (containers, algorithms) used by other quantstack packages.

%prep
%autosetup

%build
%cmake -DBUILD_TESTS:BOOL=ON
%cmake_build

#build documentation
cd %{_builddir}/%{name}-%{version}/docs
make html

%install
%cmake_install

#install documentation
mkdir -p %{buildroot}/%{_docdir}/%{name}
cp -r %{_builddir}/%{name}-%{version}/docs/build/html/* %{buildroot}/%{_docdir}/%{name}

%check
%ctest

%files devel
%license LICENSE
%doc README.md
%{_includedir}/xtl/
%{_datadir}/cmake/xtl/
%{_datadir}/pkgconfig/xtl.pc

%files doc
%doc %{_docdir}/%{name}

%changelog
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.7:
  * Use GetModuleFileNameW for wchar_t array
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.6:
  * Add missing #include <exception>
  * Fix promote_type with two complex floats and one double
  * test/CMakeLists.txt: remove extra find_package(Threads)
  * Fixed half errhandling throw except
  * Resolve issue promoting multiple std::complex
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.5:
  * added a backport of the C++20 header for integer comparison
* Tue Oct 18 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Enable unit test at package build
- Declare -devel and -doc packages as noarch
  - Drop fix_cmake_install_directory.patch
* Sun Jul 17 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 0.7.4
  - check _HAS_STD_BYTE MSVC macro in xspan implementation
  - fixed line endings in xhalf_float_impl.hpp
* Fri Mar 26 2021 Daniel Weatherill <plasteredparrot@gmail.com>
- add HTML documentation to build
- add patch to revert upstream changes to install locations
  - upstream is now installing CMake and pkg-config files in /usr/share
  fix_cmake_install_directory.patch
- update to 0.7.2
  - Removed C++14 code from xbase_fixed_string
  - test/test_xsystem.cpp: Allow for ctest executable names
  - Fixed return type in xbasic_fixed_string to be compatible with C++11
  - Added missing FreeBSD headers
  - Fixed call to sysctl
  - Added meta switch
  - Implement partial dispatch
  - Improve xbasic fixed string
  - Added xtl::executable_path and xtl::prefix_path
  - Handle complex promote type w/ different T1 and T2
  - Install as arch dependent for cmake > 3.14
  - CMake: Modernized GTest integration
  - Add support for xtl::endianness
  - Added xtraits for future simple specialization
  - Added half_float implementation
  - Improved mpl::contains implementation
  - Added are_equivalent_sequences
  - Various minor improvements
* Fri Sep  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.18:
  - Replaced throw with XTL_THROW to support disabling exceptions
  - Implemented ``index_of`` for ``mpl::vector``
  - Implemented multimethods pattern
  - Implemented visitor pattern
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.16:
  - Fixed mpark variant inclusion guards
  - Add a serialiser for xvariant to json
  - Removed capture all by reference
  - Renamed mpark variant header inclusion guard
  - Implemented value iterator for map containers
* Sat Apr 25 2020 Todd R <toddrme2178@gmail.com>
- Initial version
